==> v1.3.tar.gz: powershell/docs/list-nina-warnings.md <==
Script: *list-nina-warnings.ps1*
========================

This PowerShell script queries the current NINA warnings and lists it.

Parameters
----------
```powershell
PS> ./list-nina-warnings.ps1 [[-ARS] <String>] [<CommonParameters>]

-ARS <String>
    Specifies the official regional key in Germany ("Amtlicher Regionalschlüssel", e.g. 09777, none by default)
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-nina-warnings.ps1



⚠️ Official SEVERE WEATHER WARNING of SEVERE THUNDERSTORMS with VERY HEAVY RAIN and HAIL
   🕘 2024-06-26T07:53:00+02:00 ... 2024-06-26T08:45:00+02:00 (by DWD, Update, Severe, Immediate)

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists the current NINA warnings
.DESCRIPTION
	This PowerShell script queries the current NINA warnings and lists it.
.PARAMETER ARS
	Specifies the official regional key in Germany ("Amtlicher Regionalschlüssel", e.g. 09777, none by default)
.EXAMPLE
	PS> ./list-nina-warnings.ps1

	⚠️ Official SEVERE WEATHER WARNING of SEVERE THUNDERSTORMS with VERY HEAVY RAIN and HAIL
	   🕘 2024-06-26T07:53:00+02:00 ... 2024-06-26T08:45:00+02:00 (by DWD, Update, Severe, Immediate)
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$ARS = "")

function ListWarningsOf([string]$source, [string]$URL)
{
	Write-Progress "Loading NINA - $source warnings..."
	$warnings = (Invoke-WebRequest -URI $URL -userAgent "curl" -useBasicParsing).Content | ConvertFrom-Json
	Write-Progress -completed "Done."

	foreach($warning in $warnings) {
		$title = $warning.i18nTitle.en
		if ("$title" -eq "") { $title = $warning.i18nTitle.de }
		$startDate = $warning.startDate
		$expiresDate = $warning.expiresDate
		$severity = $warning.severity
		$urgency = $warning.urgency
		$type = $warning.type
		Write-Output ""
		Write-Output "⚠️ $title"
		if ("$type" -ne "") {
			Write-Output "   🕘 $($startDate)...$expiresDate (by $source, $type, $severity, $urgency)"
		}
	}
}

try {
	if ("$ARS" -ne "") {
		ListWarningsOf "Region" "https://warnung.bund.de/api31/dashboard/$($ARS)0000000.json"
	} else {
		ListWarningsOf "Katwarn" "https://warnung.bund.de/api31/katwarn/mapData.json"
		ListWarningsOf "DWD"     "https://warnung.bund.de/api31/dwd/mapData.json"
		ListWarningsOf "Police"  "https://warnung.bund.de/api31/police/mapData.json"
		ListWarningsOf "LHP"     "https://warnung.bund.de/api31/lhp/mapData.json"
		ListWarningsOf "Biwapp"  "https://warnung.bund.de/api31/biwapp/mapData.json"
	} 	
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-nina-warnings.ps1 as of 08/15/2024 09:50:50)*

==> v1.5.tar.gz: powershell/docs/list-nina-warnings.md <==
The *list-nina-warnings.ps1* Script
===========================

This PowerShell script queries the current NINA warnings and lists it.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/list-nina-warnings.ps1 [[-ARS] <String>] [<CommonParameters>]

-ARS <String>
    Specifies the official regional key in Germany ("Amtlicher Regionalschlüssel", e.g. 09777, none by default)
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-nina-warnings.ps1



⚠️ Official SEVERE WEATHER WARNING of SEVERE THUNDERSTORMS with VERY HEAVY RAIN and HAIL
   🕘 2024-06-26T07:53:00+02:00 ... 2024-06-26T08:45:00+02:00 (by DWD, Update, Severe, Immediate)

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists the current NINA warnings
.DESCRIPTION
	This PowerShell script queries the current NINA warnings and lists it.
.PARAMETER ARS
	Specifies the official regional key in Germany ("Amtlicher Regionalschlüssel", e.g. 09777, none by default)
.EXAMPLE
	PS> ./list-nina-warnings.ps1

	⚠️ Official SEVERE WEATHER WARNING of SEVERE THUNDERSTORMS with VERY HEAVY RAIN and HAIL
	   🕘 2024-06-26T07:53:00+02:00 ... 2024-06-26T08:45:00+02:00 (by DWD, Update, Severe, Immediate)
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$ARS = "")

function ListWarningsOf([string]$source, [string]$URL)
{
	Write-Progress "Loading NINA - $source warnings..."
	$warnings = (Invoke-WebRequest -URI $URL -userAgent "curl" -useBasicParsing).Content | ConvertFrom-Json
	Write-Progress -completed "Done."

	foreach($warning in $warnings) {
		$title = $warning.i18nTitle.en
		if ("$title" -eq "") { $title = $warning.i18nTitle.de }
		$startDate = $warning.startDate
		$expiresDate = $warning.expiresDate
		$severity = $warning.severity
		$urgency = $warning.urgency
		$type = $warning.type
		Write-Output ""
		Write-Output "⚠️ $title"
		if ("$type" -ne "") {
			Write-Output "   🕘 $($startDate)...$expiresDate (by $source, $type, $severity, $urgency)"
		}
	}
}

try {
	if ("$ARS" -ne "") {
		ListWarningsOf "Region" "https://warnung.bund.de/api31/dashboard/$($ARS)0000000.json"
	} else {
		ListWarningsOf "Katwarn" "https://warnung.bund.de/api31/katwarn/mapData.json"
		ListWarningsOf "DWD"     "https://warnung.bund.de/api31/dwd/mapData.json"
		ListWarningsOf "Police"  "https://warnung.bund.de/api31/police/mapData.json"
		ListWarningsOf "LHP"     "https://warnung.bund.de/api31/lhp/mapData.json"
		ListWarningsOf "Biwapp"  "https://warnung.bund.de/api31/biwapp/mapData.json"
	} 	
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 05/12/2025 22:02:55)*
